@@ -7,6 +7,7 @@
 module Network.Wai.Handler.Warp.Response (
     sendResponse,
     sanitizeHeaderValue, -- for testing
+    --  Provided here for backwards compatibility.
     warpVersion,
     hasBody,
     replaceHeader,
@@ -31,13 +32,11 @@ import Data.Streaming.ByteString.Builder (
     newByteStringBuilderRecv,
     reuseBufferStrategy,
  )
-import Data.Version (showVersion)
 import Data.Word8 (_cr, _lf, _space, _tab)
 import qualified Network.HTTP.Types as H
 import qualified Network.HTTP.Types.Header as H
 import Network.Wai
 import Network.Wai.Internal
-import qualified Paths_warp
 import qualified System.TimeManager as T
 
 import Network.Wai.Handler.Warp.Buffer (toBuilderBuffer)
@@ -479,10 +478,6 @@ addDate getdate rspidxhdr hdrs = case rspidxhdr ! fromEnum ResDate of
 
 ----------------------------------------------------------------
 
--- | The version of Warp.
-warpVersion :: String
-warpVersion = showVersion Paths_warp.version
-
 {-# INLINE addServer #-}
 addServer
     :: HeaderValue -> IndexedHeader -> H.ResponseHeaders -> H.ResponseHeaders
